@@ -627,8 +627,8 @@ parse_cmd(const char *cmd, const char *event)
 			p++;
 			if (*p == 'e') {
 				/* handle an event expansion */
-				int size;
-				size = snprintf(&buf[i], size, "%s", event);
+				int size = sizeof(buf) - i;
+				size = snprintf(buf+i, size, "%s", event);
 				i += size;
 				p++;
 				continue;
